==> kmess_1.4.3.orig.tar.gz: kmess-1.4.3/kmess/kmesstest.h <==
/***************************************************************************
                          kmesstest.h  -  description
                             -------------------
    begin                : Sun Jan 5 2003
    copyright            : (C) 2003 by Mike K. Bennett
    email                : mkb137b@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMESSTEST_H
#define KMESSTEST_H

#include "kmessdebug.h"  // for KMESSTEST

#include <qobject.h>

// forward declarations
class KMess;

/**A class responsible for testing the other classes.
  *@author Mike K. Bennett
  */

class KMessTest : public QObject
{
  Q_OBJECT

  public:
    // The constructor
               KMessTest(KMess *kmess);
    // The destructor
              ~KMessTest();
    // The main testing function
    void       test();

#ifdef KMESSTEST
  private: // Private methods
    void       testNotificationConnection();
    void       testContactListWithNotificationConnection();
    void       testConnect();
    void       testSettings();
    void       testSwitchboardConnection();
    void       testNotifications();
    void       testUpnpConnection();
#endif

  private: // Private attributes
    // A pointer to the main widget, also used to gain access to all its attributes
    KMess     *kmess_;
};

#endif

==> kmess_1.5.orig.tar.gz: kmess-1.5/kmess/kmesstest.h <==
/***************************************************************************
                          kmesstest.h  -  description
                             -------------------
    begin                : Sun Jan 5 2003
    copyright            : (C) 2003 by Mike K. Bennett
    email                : mkb137b@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMESSTEST_H
#define KMESSTEST_H

#include "kmessdebug.h"  // for KMESSTEST

#include <qobject.h>

// forward declarations
class KMess;

/**
 * @brief A class responsible for testing the other classes.
 *
 * This class can be used by uncommenting a few lines in main.cpp.
 * New functions can be added to implement various test cases,
 * like opening chat windows without logging in.
 * Most of these functions are included in an <code>\#ifdef</code> block,
 * so they are not compiled in the release version.
 *
 * @author Mike K. Bennett
 * @ingroup Root
 */
class KMessTest : public QObject
{
  Q_OBJECT

  public:
    // The constructor
               KMessTest(KMess *kmess);
    // The destructor
              ~KMessTest();
    // The main testing function
    void       test();

#ifdef KMESSTEST
  private: // Private methods
    void       testTransferWindow();
    void       testChatWindow();
    void       testNotificationConnection();
    void       testContactListWithNotificationConnection();
    void       testConnect();
    void       testSettings();
    void       testSwitchboardConnection();
    void       testNotifications();
    void       testNowListening();
    void       testSoapConnection();
    void       testUpnpConnection();
    void       testXslTransformation();
#endif

  private: // Private attributes
    // A pointer to the main widget, also used to gain access to all its attributes
    KMess     *kmess_;
};

#endif
